BootCapabilitySet

Struct BootCapabilitySet 

pub struct BootCapabilitySet { /* private fields */ }
The complete set of initial capabilities for the root task.

This struct describes all capabilities that should be created during kernel boot and granted to the root task.

Implementations

Source

impl BootCapabilitySet

pub const fn new() -> BootCapabilitySet

Creates an empty boot capability set.

pub fn minimal(root_task_id: u64) -> BootCapabilitySet

Creates a minimal boot set with essential capabilities.

pub fn full( root_task_id: u64, memory_start: u64, memory_size: u64, rvf_object_id: u64, rvf_hash: u64, ) -> BootCapabilitySet

Creates a full boot set with all standard capabilities.

pub fn add_memory_region(&mut self, object_id: u64, start_addr: u64) -> bool

Adds a memory region capability.

pub fn add_readonly_region(&mut self, object_id: u64, start_addr: u64) -> bool

Adds a read-only memory region (e.g., ROM).

pub fn set_rvf_package(&mut self, object_id: u64, package_hash: u64)

Sets the RVF package capability.

pub fn set_witness_log(&mut self, object_id: u64)

Sets the witness log capability.

pub fn set_interrupt_queue(&mut self, object_id: u64, irq_mask: u64)

Sets the interrupt queue capability.

pub fn set_timer(&mut self, object_id: u64)

Sets the timer capability.

pub fn set_root_task(&mut self, object_id: u64)

Sets the root task capability.

pub fn set_vector_store(&mut self, object_id: u64, dimension: u64)

Sets the vector store capability.

pub fn set_proof_graph(&mut self, object_id: u64)

Sets the proof graph capability.

pub const fn memory_region_count(&self) -> usize

Returns the number of memory regions.

pub fn total_count(&self) -> usize

Returns the total number of capabilities in the set.

pub fn iter(&self) -> impl Iterator<Item = &InitialCapability>

Returns an iterator over all capabilities in the set.