CapabilityDistribution

Struct CapabilityDistribution 

pub struct CapabilityDistribution {
    pub component_grants: [Option<ComponentCapabilityGrant>; 256],
    pub grant_count: usize,
    pub root_dropped_to_minimum: bool,
    pub root_minimum_set: MinimumCapabilitySet,
}
Capability distribution result from Stage 3.

Fields

component_grants: [Option<ComponentCapabilityGrant>; 256]

Per-component capability grants (fixed-size no_std variant).

grant_count: usize

Number of active grants in the component_grants array.

root_dropped_to_minimum: bool

SEC-001: Whether root task has been dropped to minimum set.

root_minimum_set: MinimumCapabilitySet

The minimum capability set for root task after drop.

Implementations

Source

impl CapabilityDistribution

pub fn from_manifest( manifest: &RvfManifest, _boot_capabilities: &BootCapabilitySet, ) -> Result<Self, KernelError>

Creates a capability distribution from a manifest.

pub fn grant_count(&self) -> usize

Returns the number of component grants.